@@ -6,8 +6,9 @@ from sys import exit, argv as sys_argv
 from subprocess import Popen
 from pathlib import Path
 
-from tools import get_free_port, OutlineKey
-
+from pyoutline_tools import (
+    get_free_port, OutlineKey
+)
 COLORS = [
     'red','cyan','blue','green',
     'white','yellow','magenta',
@@ -46,7 +47,7 @@ def safe_cli():
     '--port', '-p', type=click.IntRange(49152,65535),
     help='Listener proxy port'
 )
-def to_shadowsocks(outline_key, random_port, port):
+def to_ss(outline_key, random_port, port):
     """Will transform Outline Proxy Key/file with Keys to ShadowSocks"""
 
     keys = Path(outline_key)
@@ -61,7 +62,7 @@ def to_shadowsocks(outline_key, random_port, port):
         try:
             ok = OutlineKey(key)
             ss = ok.shadowsocks(random_port=random_port, port=port)
-            click.echo(bright_black(ss + '\n'))
+            click.echo(bright_black(ss))
         except ValueError:
             click.echo(red('Invalid Key specified!'))
 
@@ -95,6 +96,7 @@ def client(outline_key, random_port, port, offset):
     
     if offset < 1 or offset > len(keys):
         click.echo(red('Invalid offset specified!'))
+        exit()
 
     enter, next_ = blue('ENTER'), blue('NEXT')
     ctrld, previ = magenta('CTRL+D'), magenta('PREVIOUS')
@@ -108,7 +110,8 @@ def client(outline_key, random_port, port, offset):
         )
     else:
         click.echo(f"\n@ Press {ctrlc} to close connection and {exit_}")
-
+    
+    replace_ss = False # If ss-local fails will be used sslocal
     current_key_position = 0 if not offset else offset - 1
 
     while True:
@@ -130,7 +133,11 @@ def client(outline_key, random_port, port, offset):
 
             ss = ok.shadowsocks(random_port=random_port, port=port)
             try:
+                if replace_ss:
+                    ss = ss.replace('ss-local', 'sslocal')
+
                 ss_process = Popen(ss.replace('"','').split(' '))
+
                 if len(keys) == 1:
                     ss_process.wait()
                     exit()
@@ -138,6 +145,7 @@ def client(outline_key, random_port, port, offset):
                     getpass(prompt=''); ss_process.terminate()
                     print('\x1b[1A', end='') # This will move cursor up
                     current_key_position += 1; continue
+
             except EOFError:
                 if current_key_position > 0:
                     current_key_position -= 1
@@ -147,9 +155,14 @@ def client(outline_key, random_port, port, offset):
 
         except ValueError:
             click.echo(red('Invalid Key specified!'))
+            exit(1)
         except FileNotFoundError:
-            ss = ss.replace('ss-local', 'sslocal')
-            call(ss.replace('"','').split(' '))
+            if replace_ss:
+                click.echo(red('You should install ShadowSocks'))
+                exit(1)
+            else:
+                click.echo(yellow('Can\'t find ss-local. Try to use sslocal...'))
+                replace_ss = True
         except Exception as e:
             click.echo(red(e))
             exit(1)
